@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.10.2.1.2.18 $
+// $Revision: 1.10.2.1.2.20 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -80,7 +80,7 @@ function xnpmemoGetListBlock( $item_basic ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -102,7 +102,7 @@ function xnpmemoGetDetailBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   $tpl->assign( $xoopsTpl->get_template_vars() );
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( 'editable', xnp_get_item_permission( $_SESSION['XNPSID'], $item_id, OP_MODIFY ) );
@@ -124,7 +124,7 @@ function xnpmemoGetPrinterFriendlyDetailBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   $tpl->assign( $xoopsTpl->get_template_vars() );
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( 'editable', xnp_get_item_permission( $_SESSION['XNPSID'], $item_id, OP_MODIFY ) );
@@ -160,7 +160,7 @@ function xnpmemoGetRegisterBlock() {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
   $tpl->assign( 'basic', $basic );
@@ -192,7 +192,7 @@ function xnpmemoGetEditBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -237,7 +237,7 @@ function xnpmemoGetConfirmBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -389,7 +389,7 @@ function xnpmemoGetAdvancedSearchBlock( &$search_var ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
