@@ -1,5 +1,5 @@
 <?php
-// $Id: ex_assign.php,v 1.1.2.3 2006/06/29 01:28:25 makotonton Exp $
+// $Id: ex_assign.php,v 1.2 2006/05/30 05:27:21 aga4096 Exp $
 // FILE		::	ex_assign.php
 // AUTHOR	::	Ryuji AMANO <info@joetsu.info>
 // WEB		::	Ryu's Planning <http://ryus.joetsu.info/>
@@ -18,14 +18,11 @@ if ( is_object($xoopsModule) ) {
 	$this->assign('ex_moduledir', $xoopsModule->getVar('dirname'));
 }
 
-require_once XOOPS_ROOT_PATH."/modules/system/blocks/system_blocks.php";
-$myts =& MyTextSanitizer::getInstance();
-$mainmenu = b_system_main_show();
-foreach($mainmenu["modules"] as $module){
-	if(count($module["name"]) > 0 && $module["name"] !== 'XooNIps' && $module["name"] !== NULL && strstr($module["directory"], "xnp") == FALSE ) {
-		$dir[] = $myts -> makeTareaData4Show($module);
-		$this->assign("mod", $dir);
-	}
+if ( file_exists(XOOPS_ROOT_PATH . '/modules/xoonips/blocks/xoonips_blocks.php') ){
+	include_once XOOPS_ROOT_PATH . '/modules/xoonips/blocks/xoonips_blocks.php';
+	$search_block = b_xoonips_quick_search_show();
+	if ( $search_block )
+		$this->assign('search_block', $search_block );
 }
 
 ?>
