@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.1.2.10 $
+// $Revision: 1.1.2.12 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -213,7 +213,7 @@ class XooNIpsUtilityDownload extends XooNIpsUtility {
     if ( ! empty( $file_size ) ) {
       header( 'Content-Length: '.$file_size );
     }
-    header( 'Content-Type: "'.$mime_type.'"' );
+    header( 'Content-Type: '.$mime_type );
   }
 
   /**
